# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: witnet.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='witnet.proto',
  package='witnet',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0cwitnet.proto\x12\x06witnet\"\xfd\x03\n\x07Message\x12\r\n\x05magic\x18\x01 \x01(\r\x12%\n\x04kind\x18\x02 \x01(\x0b\x32\x17.witnet.Message.Command\x1a\xbb\x03\n\x07\x43ommand\x12\"\n\x07Version\x18\x01 \x01(\x0b\x32\x0f.witnet.VersionH\x00\x12 \n\x06Verack\x18\x02 \x01(\x0b\x32\x0e.witnet.VerackH\x00\x12$\n\x08GetPeers\x18\x03 \x01(\x0b\x32\x10.witnet.GetPeersH\x00\x12\x1e\n\x05Peers\x18\x04 \x01(\x0b\x32\r.witnet.PeersH\x00\x12\x1e\n\x05\x42lock\x18\x05 \x01(\x0b\x32\r.witnet.BlockH\x00\x12>\n\x15InventoryAnnouncement\x18\x06 \x01(\x0b\x32\x1d.witnet.InventoryAnnouncementH\x00\x12\x34\n\x10InventoryRequest\x18\x07 \x01(\x0b\x32\x18.witnet.InventoryRequestH\x00\x12(\n\nLastBeacon\x18\x08 \x01(\x0b\x32\x12.witnet.LastBeaconH\x00\x12*\n\x0bTransaction\x18\t \x01(\x0b\x32\x13.witnet.TransactionH\x00\x12\x30\n\x0eSuperBlockVote\x18\n \x01(\x0b\x32\x16.witnet.SuperBlockVoteH\x00\x42\x06\n\x04kind\"\xce\x01\n\x07Version\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x14\n\x0c\x63\x61pabilities\x18\x03 \x01(\x06\x12\'\n\x0esender_address\x18\x04 \x01(\x0b\x32\x0f.witnet.Address\x12)\n\x10receiver_address\x18\x05 \x01(\x0b\x32\x0f.witnet.Address\x12\x12\n\nuser_agent\x18\x06 \x01(\t\x12\x12\n\nlast_epoch\x18\x07 \x01(\x07\x12\r\n\x05nonce\x18\x08 \x01(\x06\"\x08\n\x06Verack\"\n\n\x08GetPeers\"\'\n\x05Peers\x12\x1e\n\x05peers\x18\x01 \x03(\x0b\x32\x0f.witnet.Address\"\x88\x08\n\x05\x42lock\x12/\n\x0c\x62lock_header\x18\x01 \x01(\x0b\x32\x19.witnet.Block.BlockHeader\x12)\n\tblock_sig\x18\x02 \x01(\x0b\x32\x16.witnet.KeyedSignature\x12-\n\x04txns\x18\x03 \x01(\x0b\x32\x1f.witnet.Block.BlockTransactions\x1a\x38\n\x15\x42lockEligibilityClaim\x12\x1f\n\x05proof\x18\x01 \x01(\x0b\x32\x10.witnet.VrfProof\x1a\x88\x04\n\x0b\x42lockHeader\x12\x0f\n\x07version\x18\x01 \x01(\r\x12(\n\x06\x62\x65\x61\x63on\x18\x02 \x01(\x0b\x32\x18.witnet.CheckpointBeacon\x12@\n\x0cmerkle_roots\x18\x03 \x01(\x0b\x32*.witnet.Block.BlockHeader.BlockMerkleRoots\x12\x32\n\x05proof\x18\x04 \x01(\x0b\x32#.witnet.Block.BlockEligibilityClaim\x12\x30\n\x10\x62n256_public_key\x18\x05 \x01(\x0b\x32\x16.witnet.Bn256PublicKey\x1a\x95\x02\n\x10\x42lockMerkleRoots\x12\x1f\n\tmint_hash\x18\x01 \x01(\x0b\x32\x0c.witnet.Hash\x12)\n\x13vt_hash_merkle_root\x18\x02 \x01(\x0b\x32\x0c.witnet.Hash\x12)\n\x13\x64r_hash_merkle_root\x18\x03 \x01(\x0b\x32\x0c.witnet.Hash\x12-\n\x17\x63ommit_hash_merkle_root\x18\x04 \x01(\x0b\x32\x0c.witnet.Hash\x12-\n\x17reveal_hash_merkle_root\x18\x05 \x01(\x0b\x32\x0c.witnet.Hash\x12,\n\x16tally_hash_merkle_root\x18\x06 \x01(\x0b\x32\x0c.witnet.Hash\x1a\xae\x02\n\x11\x42lockTransactions\x12%\n\x04mint\x18\x01 \x01(\x0b\x32\x17.witnet.MintTransaction\x12\x32\n\x13value_transfer_txns\x18\x02 \x03(\x0b\x32\x15.witnet.VTTransaction\x12\x30\n\x11\x64\x61ta_request_txns\x18\x03 \x03(\x0b\x32\x15.witnet.DRTransaction\x12.\n\x0b\x63ommit_txns\x18\x04 \x03(\x0b\x32\x19.witnet.CommitTransaction\x12.\n\x0breveal_txns\x18\x05 \x03(\x0b\x32\x19.witnet.RevealTransaction\x12,\n\ntally_txns\x18\x06 \x03(\x0b\x32\x18.witnet.TallyTransaction\"B\n\x15InventoryAnnouncement\x12)\n\tinventory\x18\x01 \x03(\x0b\x32\x16.witnet.InventoryEntry\"=\n\x10InventoryRequest\x12)\n\tinventory\x18\x01 \x03(\x0b\x32\x16.witnet.InventoryEntry\"H\n\nLastBeacon\x12:\n\x18highest_block_checkpoint\x18\x01 \x01(\x0b\x32\x18.witnet.CheckpointBeacon\"K\n\rOutputPointer\x12$\n\x0etransaction_id\x18\x01 \x01(\x0b\x32\x0c.witnet.Hash\x12\x14\n\x0coutput_index\x18\x02 \x01(\r\"[\n\x13ValueTransferOutput\x12\"\n\x03pkh\x18\x01 \x01(\x0b\x32\x15.witnet.PublicKeyHash\x12\r\n\x05value\x18\x02 \x01(\x04\x12\x11\n\ttime_lock\x18\x03 \x01(\x04\"\xbc\x06\n\x11\x44\x61taRequestOutput\x12:\n\x0c\x64\x61ta_request\x18\x01 \x01(\x0b\x32$.witnet.DataRequestOutput.RADRequest\x12\x16\n\x0ewitness_reward\x18\x02 \x01(\x04\x12\x11\n\twitnesses\x18\x03 \x01(\r\x12\x12\n\ncommit_fee\x18\x04 \x01(\x04\x12\x12\n\nreveal_fee\x18\x05 \x01(\x04\x12\x11\n\ttally_fee\x18\x06 \x01(\x04\x12 \n\x18min_consensus_percentage\x18\x07 \x01(\r\x12\x12\n\ncollateral\x18\x08 \x01(\x04\x1a\xce\x04\n\nRADRequest\x12\x11\n\ttime_lock\x18\x01 \x01(\x04\x12\x42\n\x08retrieve\x18\x02 \x03(\x0b\x32\x30.witnet.DataRequestOutput.RADRequest.RADRetrieve\x12\x44\n\taggregate\x18\x03 \x01(\x0b\x32\x31.witnet.DataRequestOutput.RADRequest.RADAggregate\x12<\n\x05tally\x18\x04 \x01(\x0b\x32-.witnet.DataRequestOutput.RADRequest.RADTally\x1a%\n\tRADFilter\x12\n\n\x02op\x18\x01 \x01(\r\x12\x0c\n\x04\x61rgs\x18\x02 \x01(\x0c\x1a\x66\n\x0bRADRetrieve\x12:\n\x04kind\x18\x01 \x01(\x0e\x32,.witnet.DataRequestOutput.RADRequest.RADType\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0e\n\x06script\x18\x03 \x01(\x0c\x1a`\n\x0cRADAggregate\x12?\n\x07\x66ilters\x18\x01 \x03(\x0b\x32..witnet.DataRequestOutput.RADRequest.RADFilter\x12\x0f\n\x07reducer\x18\x02 \x01(\r\x1a\\\n\x08RADTally\x12?\n\x07\x66ilters\x18\x01 \x03(\x0b\x32..witnet.DataRequestOutput.RADRequest.RADFilter\x12\x0f\n\x07reducer\x18\x02 \x01(\r\"\x16\n\x07RADType\x12\x0b\n\x07HttpGet\x10\x00\"6\n\x05Input\x12-\n\x0eoutput_pointer\x18\x01 \x01(\x0b\x32\x15.witnet.OutputPointer\"`\n\x11VTTransactionBody\x12\x1d\n\x06inputs\x18\x01 \x03(\x0b\x32\r.witnet.Input\x12,\n\x07outputs\x18\x02 \x03(\x0b\x32\x1b.witnet.ValueTransferOutput\"d\n\rVTTransaction\x12\'\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x19.witnet.VTTransactionBody\x12*\n\nsignatures\x18\x02 \x03(\x0b\x32\x16.witnet.KeyedSignature\"\x8e\x01\n\x11\x44RTransactionBody\x12\x1d\n\x06inputs\x18\x01 \x03(\x0b\x32\r.witnet.Input\x12,\n\x07outputs\x18\x02 \x03(\x0b\x32\x1b.witnet.ValueTransferOutput\x12,\n\tdr_output\x18\x03 \x01(\x0b\x32\x19.witnet.DataRequestOutput\"d\n\rDRTransaction\x12\'\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x19.witnet.DRTransactionBody\x12*\n\nsignatures\x18\x02 \x03(\x0b\x32\x16.witnet.KeyedSignature\"\x92\x02\n\x15\x43ommitTransactionBody\x12 \n\ndr_pointer\x18\x01 \x01(\x0b\x32\x0c.witnet.Hash\x12 \n\ncommitment\x18\x02 \x01(\x0b\x32\x0c.witnet.Hash\x12\x32\n\x05proof\x18\x03 \x01(\x0b\x32#.witnet.DataRequestEligibilityClaim\x12!\n\ncollateral\x18\x04 \x03(\x0b\x32\r.witnet.Input\x12,\n\x07outputs\x18\x05 \x03(\x0b\x32\x1b.witnet.ValueTransferOutput\x12\x30\n\x10\x62n256_public_key\x18\x06 \x01(\x0b\x32\x16.witnet.Bn256PublicKey\"l\n\x11\x43ommitTransaction\x12+\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x1d.witnet.CommitTransactionBody\x12*\n\nsignatures\x18\x02 \x03(\x0b\x32\x16.witnet.KeyedSignature\"m\n\x15RevealTransactionBody\x12 \n\ndr_pointer\x18\x01 \x01(\x0b\x32\x0c.witnet.Hash\x12\x0e\n\x06reveal\x18\x02 \x01(\x0c\x12\"\n\x03pkh\x18\x03 \x01(\x0b\x32\x15.witnet.PublicKeyHash\"l\n\x11RevealTransaction\x12+\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x1d.witnet.RevealTransactionBody\x12*\n\nsignatures\x18\x02 \x03(\x0b\x32\x16.witnet.KeyedSignature\"\xd3\x01\n\x10TallyTransaction\x12 \n\ndr_pointer\x18\x01 \x01(\x0b\x32\x0c.witnet.Hash\x12\r\n\x05tally\x18\x02 \x01(\x0c\x12,\n\x07outputs\x18\x03 \x03(\x0b\x32\x1b.witnet.ValueTransferOutput\x12/\n\x10out_of_consensus\x18\x04 \x03(\x0b\x32\x15.witnet.PublicKeyHash\x12/\n\x10\x65rror_committers\x18\x05 \x03(\x0b\x32\x15.witnet.PublicKeyHash\"N\n\x0fMintTransaction\x12\r\n\x05\x65poch\x18\x01 \x01(\x07\x12,\n\x07outputs\x18\x02 \x03(\x0b\x32\x1b.witnet.ValueTransferOutput\"\xa1\x02\n\x0bTransaction\x12.\n\rValueTransfer\x18\x01 \x01(\x0b\x32\x15.witnet.VTTransactionH\x00\x12,\n\x0b\x44\x61taRequest\x18\x02 \x01(\x0b\x32\x15.witnet.DRTransactionH\x00\x12+\n\x06\x43ommit\x18\x03 \x01(\x0b\x32\x19.witnet.CommitTransactionH\x00\x12+\n\x06Reveal\x18\x04 \x01(\x0b\x32\x19.witnet.RevealTransactionH\x00\x12)\n\x05Tally\x18\x05 \x01(\x0b\x32\x18.witnet.TallyTransactionH\x00\x12\'\n\x04Mint\x18\x06 \x01(\x0b\x32\x17.witnet.MintTransactionH\x00\x42\x06\n\x04kind\" \n\x04Hash\x12\x10\n\x06SHA256\x18\x01 \x01(\x0cH\x00\x42\x06\n\x04kind\"!\n\x12Secp256k1Signature\x12\x0b\n\x03\x64\x65r\x18\x01 \x01(\x0c\"D\n\tSignature\x12/\n\tSecp256k1\x18\x01 \x01(\x0b\x32\x1a.witnet.Secp256k1SignatureH\x00\x42\x06\n\x04kind\"#\n\x0e\x42n256Signature\x12\x11\n\tsignature\x18\x01 \x01(\x0c\"\x1f\n\tPublicKey\x12\x12\n\npublic_key\x18\x01 \x01(\x0c\"$\n\x0e\x42n256PublicKey\x12\x12\n\npublic_key\x18\x01 \x01(\x0c\"\x1d\n\rPublicKeyHash\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\"]\n\x0eKeyedSignature\x12$\n\tsignature\x18\x01 \x01(\x0b\x32\x11.witnet.Signature\x12%\n\npublic_key\x18\x02 \x01(\x0b\x32\x11.witnet.PublicKey\"l\n\x13\x42n256KeyedSignature\x12)\n\tsignature\x18\x01 \x01(\x0b\x32\x16.witnet.Bn256Signature\x12*\n\npublic_key\x18\x02 \x01(\x0b\x32\x16.witnet.Bn256PublicKey\"\x1a\n\x07\x41\x64\x64ress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\"M\n\x10\x43heckpointBeacon\x12\x12\n\ncheckpoint\x18\x01 \x01(\x07\x12%\n\x0fhash_prev_block\x18\x02 \x01(\x0b\x32\x0c.witnet.Hash\"H\n\rCheckpointVRF\x12\x12\n\ncheckpoint\x18\x01 \x01(\x07\x12#\n\rhash_prev_vrf\x18\x02 \x01(\x0b\x32\x0c.witnet.Hash\"S\n\x0eInventoryEntry\x12\x1d\n\x05\x42lock\x18\x01 \x01(\x0b\x32\x0c.witnet.HashH\x00\x12\x1a\n\x02Tx\x18\x02 \x01(\x0b\x32\x0c.witnet.HashH\x00\x42\x06\n\x04kind\"\x83\x04\n\x12\x43onsensusConstants\x12!\n\x19\x63heckpoint_zero_timestamp\x18\x01 \x01(\x03\x12\x1a\n\x12\x63heckpoints_period\x18\x02 \x01(\r\x12$\n\x0e\x62ootstrap_hash\x18\x03 \x01(\x0b\x32\x0c.witnet.Hash\x12\"\n\x0cgenesis_hash\x18\x04 \x01(\x0b\x32\x0c.witnet.Hash\x12\x18\n\x10max_block_weight\x18\x05 \x01(\r\x12\x17\n\x0f\x61\x63tivity_period\x18\x06 \x01(\r\x12$\n\x1creputation_expire_alpha_diff\x18\x07 \x01(\r\x12\x1b\n\x13reputation_issuance\x18\x08 \x01(\r\x12 \n\x18reputation_issuance_stop\x18\t \x01(\r\x12&\n\x1ereputation_penalization_factor\x18\n \x01(\x01\x12\x1c\n\x14mining_backup_factor\x18\x0b \x01(\r\x12!\n\x19mining_replication_factor\x18\x0c \x01(\r\x12\x1a\n\x12\x63ollateral_minimum\x18\r \x01(\x04\x12\x16\n\x0e\x63ollateral_age\x18\x0e \x01(\r\x12\x19\n\x11superblock_period\x18\x0f \x01(\r\x12\x14\n\x0c\x65xtra_rounds\x18\x10 \x01(\r\"@\n\x08VrfProof\x12\r\n\x05proof\x18\x01 \x01(\x0c\x12%\n\npublic_key\x18\x02 \x01(\x0b\x32\x11.witnet.PublicKey\"`\n\x15\x44\x61taRequestVrfMessage\x12(\n\tvrf_input\x18\x01 \x01(\x0b\x32\x15.witnet.CheckpointVRF\x12\x1d\n\x07\x64r_hash\x18\x02 \x01(\x0b\x32\x0c.witnet.Hash\">\n\x1b\x44\x61taRequestEligibilityClaim\x12\x1f\n\x05proof\x18\x01 \x01(\x0b\x32\x10.witnet.VrfProof\"\xe1\x01\n\nSuperBlock\x12\x1e\n\x08\x61rs_root\x18\x01 \x01(\x0b\x32\x0c.witnet.Hash\x12\'\n\x11\x64\x61ta_request_root\x18\x02 \x01(\x0b\x32\x0c.witnet.Hash\x12\r\n\x05index\x18\x03 \x01(\r\x12 \n\nlast_block\x18\x04 \x01(\x0b\x32\x0c.witnet.Hash\x12\x37\n!last_block_in_previous_superblock\x18\x05 \x01(\x0b\x32\x0c.witnet.Hash\x12 \n\ntally_root\x18\x06 \x01(\x0b\x32\x0c.witnet.Hash\"\xb7\x01\n\x0eSuperBlockVote\x12/\n\x0f\x62n256_signature\x18\x01 \x01(\x0b\x32\x16.witnet.Bn256Signature\x12\x33\n\x13secp256k1_signature\x18\x02 \x01(\x0b\x32\x16.witnet.KeyedSignature\x12%\n\x0fsuperblock_hash\x18\x03 \x01(\x0b\x32\x0c.witnet.Hash\x12\x18\n\x10superblock_index\x18\x04 \x01(\x07\x62\x06proto3'
)



_DATAREQUESTOUTPUT_RADREQUEST_RADTYPE = _descriptor.EnumDescriptor(
  name='RADType',
  full_name='witnet.DataRequestOutput.RADRequest.RADType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HttpGet', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3025,
  serialized_end=3047,
)
_sym_db.RegisterEnumDescriptor(_DATAREQUESTOUTPUT_RADREQUEST_RADTYPE)


_MESSAGE_COMMAND = _descriptor.Descriptor(
  name='Command',
  full_name='witnet.Message.Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Version', full_name='witnet.Message.Command.Version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Verack', full_name='witnet.Message.Command.Verack', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='GetPeers', full_name='witnet.Message.Command.GetPeers', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Peers', full_name='witnet.Message.Command.Peers', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Block', full_name='witnet.Message.Command.Block', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='InventoryAnnouncement', full_name='witnet.Message.Command.InventoryAnnouncement', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='InventoryRequest', full_name='witnet.Message.Command.InventoryRequest', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LastBeacon', full_name='witnet.Message.Command.LastBeacon', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Transaction', full_name='witnet.Message.Command.Transaction', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SuperBlockVote', full_name='witnet.Message.Command.SuperBlockVote', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='witnet.Message.Command.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=91,
  serialized_end=534,
)

_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='witnet.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='magic', full_name='witnet.Message.magic', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='witnet.Message.kind', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MESSAGE_COMMAND, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=534,
)


_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='witnet.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='witnet.Version.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='witnet.Version.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capabilities', full_name='witnet.Version.capabilities', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender_address', full_name='witnet.Version.sender_address', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver_address', full_name='witnet.Version.receiver_address', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_agent', full_name='witnet.Version.user_agent', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_epoch', full_name='witnet.Version.last_epoch', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='witnet.Version.nonce', index=7,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=743,
)


_VERACK = _descriptor.Descriptor(
  name='Verack',
  full_name='witnet.Verack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=146,
)


_GETPEERS = _descriptor.Descriptor(
  name='GetPeers',
  full_name='witnet.GetPeers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=182,
)


_PEERS = _descriptor.Descriptor(
  name='Peers',
  full_name='witnet.Peers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peers', full_name='witnet.Peers.peers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=767,
  serialized_end=806,
)


_BLOCK_BLOCKELIGIBILITYCLAIM = _descriptor.Descriptor(
  name='BlockEligibilityClaim',
  full_name='witnet.Block.BlockEligibilityClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proof', full_name='witnet.Block.BlockEligibilityClaim.proof', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=957,
  serialized_end=1013,
)

_BLOCK_BLOCKHEADER_BLOCKMERKLEROOTS = _descriptor.Descriptor(
  name='BlockMerkleRoots',
  full_name='witnet.Block.BlockHeader.BlockMerkleRoots',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mint_hash', full_name='witnet.Block.BlockHeader.BlockMerkleRoots.mint_hash', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vt_hash_merkle_root', full_name='witnet.Block.BlockHeader.BlockMerkleRoots.vt_hash_merkle_root', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dr_hash_merkle_root', full_name='witnet.Block.BlockHeader.BlockMerkleRoots.dr_hash_merkle_root', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit_hash_merkle_root', full_name='witnet.Block.BlockHeader.BlockMerkleRoots.commit_hash_merkle_root', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reveal_hash_merkle_root', full_name='witnet.Block.BlockHeader.BlockMerkleRoots.reveal_hash_merkle_root', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tally_hash_merkle_root', full_name='witnet.Block.BlockHeader.BlockMerkleRoots.tally_hash_merkle_root', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1259,
  serialized_end=1536,
)

_BLOCK_BLOCKHEADER = _descriptor.Descriptor(
  name='BlockHeader',
  full_name='witnet.Block.BlockHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='witnet.Block.BlockHeader.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beacon', full_name='witnet.Block.BlockHeader.beacon', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='merkle_roots', full_name='witnet.Block.BlockHeader.merkle_roots', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof', full_name='witnet.Block.BlockHeader.proof', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bn256_public_key', full_name='witnet.Block.BlockHeader.bn256_public_key', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BLOCK_BLOCKHEADER_BLOCKMERKLEROOTS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1016,
  serialized_end=1536,
)

_BLOCK_BLOCKTRANSACTIONS = _descriptor.Descriptor(
  name='BlockTransactions',
  full_name='witnet.Block.BlockTransactions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mint', full_name='witnet.Block.BlockTransactions.mint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_transfer_txns', full_name='witnet.Block.BlockTransactions.value_transfer_txns', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_request_txns', full_name='witnet.Block.BlockTransactions.data_request_txns', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit_txns', full_name='witnet.Block.BlockTransactions.commit_txns', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reveal_txns', full_name='witnet.Block.BlockTransactions.reveal_txns', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tally_txns', full_name='witnet.Block.BlockTransactions.tally_txns', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1539,
  serialized_end=1841,
)

_BLOCK = _descriptor.Descriptor(
  name='Block',
  full_name='witnet.Block',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_header', full_name='witnet.Block.block_header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_sig', full_name='witnet.Block.block_sig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='txns', full_name='witnet.Block.txns', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BLOCK_BLOCKELIGIBILITYCLAIM, _BLOCK_BLOCKHEADER, _BLOCK_BLOCKTRANSACTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=1841,
)


_INVENTORYANNOUNCEMENT = _descriptor.Descriptor(
  name='InventoryAnnouncement',
  full_name='witnet.InventoryAnnouncement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inventory', full_name='witnet.InventoryAnnouncement.inventory', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1843,
  serialized_end=1909,
)


_INVENTORYREQUEST = _descriptor.Descriptor(
  name='InventoryRequest',
  full_name='witnet.InventoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inventory', full_name='witnet.InventoryRequest.inventory', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1911,
  serialized_end=1972,
)


_LASTBEACON = _descriptor.Descriptor(
  name='LastBeacon',
  full_name='witnet.LastBeacon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='highest_block_checkpoint', full_name='witnet.LastBeacon.highest_block_checkpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1974,
  serialized_end=2046,
)


_OUTPUTPOINTER = _descriptor.Descriptor(
  name='OutputPointer',
  full_name='witnet.OutputPointer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='witnet.OutputPointer.transaction_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_index', full_name='witnet.OutputPointer.output_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2048,
  serialized_end=2123,
)


_VALUETRANSFEROUTPUT = _descriptor.Descriptor(
  name='ValueTransferOutput',
  full_name='witnet.ValueTransferOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pkh', full_name='witnet.ValueTransferOutput.pkh', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='witnet.ValueTransferOutput.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_lock', full_name='witnet.ValueTransferOutput.time_lock', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2125,
  serialized_end=2216,
)


_DATAREQUESTOUTPUT_RADREQUEST_RADFILTER = _descriptor.Descriptor(
  name='RADFilter',
  full_name='witnet.DataRequestOutput.RADRequest.RADFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='op', full_name='witnet.DataRequestOutput.RADRequest.RADFilter.op', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='witnet.DataRequestOutput.RADRequest.RADFilter.args', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2690,
  serialized_end=2727,
)

_DATAREQUESTOUTPUT_RADREQUEST_RADRETRIEVE = _descriptor.Descriptor(
  name='RADRetrieve',
  full_name='witnet.DataRequestOutput.RADRequest.RADRetrieve',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='witnet.DataRequestOutput.RADRequest.RADRetrieve.kind', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='witnet.DataRequestOutput.RADRequest.RADRetrieve.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='script', full_name='witnet.DataRequestOutput.RADRequest.RADRetrieve.script', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2729,
  serialized_end=2831,
)

_DATAREQUESTOUTPUT_RADREQUEST_RADAGGREGATE = _descriptor.Descriptor(
  name='RADAggregate',
  full_name='witnet.DataRequestOutput.RADRequest.RADAggregate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='witnet.DataRequestOutput.RADRequest.RADAggregate.filters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reducer', full_name='witnet.DataRequestOutput.RADRequest.RADAggregate.reducer', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2833,
  serialized_end=2929,
)

_DATAREQUESTOUTPUT_RADREQUEST_RADTALLY = _descriptor.Descriptor(
  name='RADTally',
  full_name='witnet.DataRequestOutput.RADRequest.RADTally',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='witnet.DataRequestOutput.RADRequest.RADTally.filters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reducer', full_name='witnet.DataRequestOutput.RADRequest.RADTally.reducer', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2931,
  serialized_end=3023,
)

_DATAREQUESTOUTPUT_RADREQUEST = _descriptor.Descriptor(
  name='RADRequest',
  full_name='witnet.DataRequestOutput.RADRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_lock', full_name='witnet.DataRequestOutput.RADRequest.time_lock', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieve', full_name='witnet.DataRequestOutput.RADRequest.retrieve', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregate', full_name='witnet.DataRequestOutput.RADRequest.aggregate', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tally', full_name='witnet.DataRequestOutput.RADRequest.tally', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DATAREQUESTOUTPUT_RADREQUEST_RADFILTER, _DATAREQUESTOUTPUT_RADREQUEST_RADRETRIEVE, _DATAREQUESTOUTPUT_RADREQUEST_RADAGGREGATE, _DATAREQUESTOUTPUT_RADREQUEST_RADTALLY, ],
  enum_types=[
    _DATAREQUESTOUTPUT_RADREQUEST_RADTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2457,
  serialized_end=3047,
)

_DATAREQUESTOUTPUT = _descriptor.Descriptor(
  name='DataRequestOutput',
  full_name='witnet.DataRequestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_request', full_name='witnet.DataRequestOutput.data_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='witness_reward', full_name='witnet.DataRequestOutput.witness_reward', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='witnesses', full_name='witnet.DataRequestOutput.witnesses', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit_fee', full_name='witnet.DataRequestOutput.commit_fee', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reveal_fee', full_name='witnet.DataRequestOutput.reveal_fee', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tally_fee', full_name='witnet.DataRequestOutput.tally_fee', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_consensus_percentage', full_name='witnet.DataRequestOutput.min_consensus_percentage', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collateral', full_name='witnet.DataRequestOutput.collateral', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DATAREQUESTOUTPUT_RADREQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2219,
  serialized_end=3047,
)


_INPUT = _descriptor.Descriptor(
  name='Input',
  full_name='witnet.Input',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_pointer', full_name='witnet.Input.output_pointer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3049,
  serialized_end=3103,
)


_VTTRANSACTIONBODY = _descriptor.Descriptor(
  name='VTTransactionBody',
  full_name='witnet.VTTransactionBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='witnet.VTTransactionBody.inputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='witnet.VTTransactionBody.outputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3105,
  serialized_end=3201,
)


_VTTRANSACTION = _descriptor.Descriptor(
  name='VTTransaction',
  full_name='witnet.VTTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='witnet.VTTransaction.body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signatures', full_name='witnet.VTTransaction.signatures', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3203,
  serialized_end=3303,
)


_DRTRANSACTIONBODY = _descriptor.Descriptor(
  name='DRTransactionBody',
  full_name='witnet.DRTransactionBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='witnet.DRTransactionBody.inputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='witnet.DRTransactionBody.outputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dr_output', full_name='witnet.DRTransactionBody.dr_output', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3306,
  serialized_end=3448,
)


_DRTRANSACTION = _descriptor.Descriptor(
  name='DRTransaction',
  full_name='witnet.DRTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='witnet.DRTransaction.body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signatures', full_name='witnet.DRTransaction.signatures', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3450,
  serialized_end=3550,
)


_COMMITTRANSACTIONBODY = _descriptor.Descriptor(
  name='CommitTransactionBody',
  full_name='witnet.CommitTransactionBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dr_pointer', full_name='witnet.CommitTransactionBody.dr_pointer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commitment', full_name='witnet.CommitTransactionBody.commitment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proof', full_name='witnet.CommitTransactionBody.proof', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collateral', full_name='witnet.CommitTransactionBody.collateral', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='witnet.CommitTransactionBody.outputs', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bn256_public_key', full_name='witnet.CommitTransactionBody.bn256_public_key', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3553,
  serialized_end=3827,
)


_COMMITTRANSACTION = _descriptor.Descriptor(
  name='CommitTransaction',
  full_name='witnet.CommitTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='witnet.CommitTransaction.body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signatures', full_name='witnet.CommitTransaction.signatures', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3829,
  serialized_end=3937,
)


_REVEALTRANSACTIONBODY = _descriptor.Descriptor(
  name='RevealTransactionBody',
  full_name='witnet.RevealTransactionBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dr_pointer', full_name='witnet.RevealTransactionBody.dr_pointer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reveal', full_name='witnet.RevealTransactionBody.reveal', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pkh', full_name='witnet.RevealTransactionBody.pkh', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3939,
  serialized_end=4048,
)


_REVEALTRANSACTION = _descriptor.Descriptor(
  name='RevealTransaction',
  full_name='witnet.RevealTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='witnet.RevealTransaction.body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signatures', full_name='witnet.RevealTransaction.signatures', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4050,
  serialized_end=4158,
)


_TALLYTRANSACTION = _descriptor.Descriptor(
  name='TallyTransaction',
  full_name='witnet.TallyTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dr_pointer', full_name='witnet.TallyTransaction.dr_pointer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tally', full_name='witnet.TallyTransaction.tally', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='witnet.TallyTransaction.outputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='out_of_consensus', full_name='witnet.TallyTransaction.out_of_consensus', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_committers', full_name='witnet.TallyTransaction.error_committers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4161,
  serialized_end=4372,
)


_MINTTRANSACTION = _descriptor.Descriptor(
  name='MintTransaction',
  full_name='witnet.MintTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='epoch', full_name='witnet.MintTransaction.epoch', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='witnet.MintTransaction.outputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4374,
  serialized_end=4452,
)


_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='witnet.Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ValueTransfer', full_name='witnet.Transaction.ValueTransfer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='DataRequest', full_name='witnet.Transaction.DataRequest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Commit', full_name='witnet.Transaction.Commit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Reveal', full_name='witnet.Transaction.Reveal', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Tally', full_name='witnet.Transaction.Tally', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Mint', full_name='witnet.Transaction.Mint', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='witnet.Transaction.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4455,
  serialized_end=4744,
)


_HASH = _descriptor.Descriptor(
  name='Hash',
  full_name='witnet.Hash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='SHA256', full_name='witnet.Hash.SHA256', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='witnet.Hash.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4746,
  serialized_end=4778,
)


_SECP256K1SIGNATURE = _descriptor.Descriptor(
  name='Secp256k1Signature',
  full_name='witnet.Secp256k1Signature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='der', full_name='witnet.Secp256k1Signature.der', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4780,
  serialized_end=4813,
)


_SIGNATURE = _descriptor.Descriptor(
  name='Signature',
  full_name='witnet.Signature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Secp256k1', full_name='witnet.Signature.Secp256k1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='witnet.Signature.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4815,
  serialized_end=4883,
)


_BN256SIGNATURE = _descriptor.Descriptor(
  name='Bn256Signature',
  full_name='witnet.Bn256Signature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature', full_name='witnet.Bn256Signature.signature', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4885,
  serialized_end=4920,
)


_PUBLICKEY = _descriptor.Descriptor(
  name='PublicKey',
  full_name='witnet.PublicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='witnet.PublicKey.public_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4922,
  serialized_end=4953,
)


_BN256PUBLICKEY = _descriptor.Descriptor(
  name='Bn256PublicKey',
  full_name='witnet.Bn256PublicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='witnet.Bn256PublicKey.public_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4955,
  serialized_end=4991,
)


_PUBLICKEYHASH = _descriptor.Descriptor(
  name='PublicKeyHash',
  full_name='witnet.PublicKeyHash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='witnet.PublicKeyHash.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4993,
  serialized_end=5022,
)


_KEYEDSIGNATURE = _descriptor.Descriptor(
  name='KeyedSignature',
  full_name='witnet.KeyedSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature', full_name='witnet.KeyedSignature.signature', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='witnet.KeyedSignature.public_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5024,
  serialized_end=5117,
)


_BN256KEYEDSIGNATURE = _descriptor.Descriptor(
  name='Bn256KeyedSignature',
  full_name='witnet.Bn256KeyedSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature', full_name='witnet.Bn256KeyedSignature.signature', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='witnet.Bn256KeyedSignature.public_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5119,
  serialized_end=5227,
)


_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='witnet.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='witnet.Address.address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5229,
  serialized_end=5255,
)


_CHECKPOINTBEACON = _descriptor.Descriptor(
  name='CheckpointBeacon',
  full_name='witnet.CheckpointBeacon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='checkpoint', full_name='witnet.CheckpointBeacon.checkpoint', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash_prev_block', full_name='witnet.CheckpointBeacon.hash_prev_block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5257,
  serialized_end=5334,
)


_CHECKPOINTVRF = _descriptor.Descriptor(
  name='CheckpointVRF',
  full_name='witnet.CheckpointVRF',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='checkpoint', full_name='witnet.CheckpointVRF.checkpoint', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash_prev_vrf', full_name='witnet.CheckpointVRF.hash_prev_vrf', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5336,
  serialized_end=5408,
)


_INVENTORYENTRY = _descriptor.Descriptor(
  name='InventoryEntry',
  full_name='witnet.InventoryEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Block', full_name='witnet.InventoryEntry.Block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Tx', full_name='witnet.InventoryEntry.Tx', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='witnet.InventoryEntry.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5410,
  serialized_end=5493,
)


_CONSENSUSCONSTANTS = _descriptor.Descriptor(
  name='ConsensusConstants',
  full_name='witnet.ConsensusConstants',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='checkpoint_zero_timestamp', full_name='witnet.ConsensusConstants.checkpoint_zero_timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkpoints_period', full_name='witnet.ConsensusConstants.checkpoints_period', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bootstrap_hash', full_name='witnet.ConsensusConstants.bootstrap_hash', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='genesis_hash', full_name='witnet.ConsensusConstants.genesis_hash', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_block_weight', full_name='witnet.ConsensusConstants.max_block_weight', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activity_period', full_name='witnet.ConsensusConstants.activity_period', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reputation_expire_alpha_diff', full_name='witnet.ConsensusConstants.reputation_expire_alpha_diff', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reputation_issuance', full_name='witnet.ConsensusConstants.reputation_issuance', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reputation_issuance_stop', full_name='witnet.ConsensusConstants.reputation_issuance_stop', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reputation_penalization_factor', full_name='witnet.ConsensusConstants.reputation_penalization_factor', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mining_backup_factor', full_name='witnet.ConsensusConstants.mining_backup_factor', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mining_replication_factor', full_name='witnet.ConsensusConstants.mining_replication_factor', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collateral_minimum', full_name='witnet.ConsensusConstants.collateral_minimum', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collateral_age', full_name='witnet.ConsensusConstants.collateral_age', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='superblock_period', full_name='witnet.ConsensusConstants.superblock_period', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_rounds', full_name='witnet.ConsensusConstants.extra_rounds', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5496,
  serialized_end=6011,
)


_VRFPROOF = _descriptor.Descriptor(
  name='VrfProof',
  full_name='witnet.VrfProof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proof', full_name='witnet.VrfProof.proof', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='witnet.VrfProof.public_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6013,
  serialized_end=6077,
)


_DATAREQUESTVRFMESSAGE = _descriptor.Descriptor(
  name='DataRequestVrfMessage',
  full_name='witnet.DataRequestVrfMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vrf_input', full_name='witnet.DataRequestVrfMessage.vrf_input', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dr_hash', full_name='witnet.DataRequestVrfMessage.dr_hash', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6079,
  serialized_end=6175,
)


_DATAREQUESTELIGIBILITYCLAIM = _descriptor.Descriptor(
  name='DataRequestEligibilityClaim',
  full_name='witnet.DataRequestEligibilityClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proof', full_name='witnet.DataRequestEligibilityClaim.proof', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6177,
  serialized_end=6239,
)


_SUPERBLOCK = _descriptor.Descriptor(
  name='SuperBlock',
  full_name='witnet.SuperBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ars_root', full_name='witnet.SuperBlock.ars_root', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_request_root', full_name='witnet.SuperBlock.data_request_root', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='witnet.SuperBlock.index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_block', full_name='witnet.SuperBlock.last_block', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_block_in_previous_superblock', full_name='witnet.SuperBlock.last_block_in_previous_superblock', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tally_root', full_name='witnet.SuperBlock.tally_root', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6242,
  serialized_end=6467,
)


_SUPERBLOCKVOTE = _descriptor.Descriptor(
  name='SuperBlockVote',
  full_name='witnet.SuperBlockVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bn256_signature', full_name='witnet.SuperBlockVote.bn256_signature', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secp256k1_signature', full_name='witnet.SuperBlockVote.secp256k1_signature', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='superblock_hash', full_name='witnet.SuperBlockVote.superblock_hash', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='superblock_index', full_name='witnet.SuperBlockVote.superblock_index', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6470,
  serialized_end=6653,
)

_MESSAGE_COMMAND.fields_by_name['Version'].message_type = _VERSION
_MESSAGE_COMMAND.fields_by_name['Verack'].message_type = _VERACK
_MESSAGE_COMMAND.fields_by_name['GetPeers'].message_type = _GETPEERS
_MESSAGE_COMMAND.fields_by_name['Peers'].message_type = _PEERS
_MESSAGE_COMMAND.fields_by_name['Block'].message_type = _BLOCK
_MESSAGE_COMMAND.fields_by_name['InventoryAnnouncement'].message_type = _INVENTORYANNOUNCEMENT
_MESSAGE_COMMAND.fields_by_name['InventoryRequest'].message_type = _INVENTORYREQUEST
_MESSAGE_COMMAND.fields_by_name['LastBeacon'].message_type = _LASTBEACON
_MESSAGE_COMMAND.fields_by_name['Transaction'].message_type = _TRANSACTION
_MESSAGE_COMMAND.fields_by_name['SuperBlockVote'].message_type = _SUPERBLOCKVOTE
_MESSAGE_COMMAND.containing_type = _MESSAGE
_MESSAGE_COMMAND.oneofs_by_name['kind'].fields.append(
  _MESSAGE_COMMAND.fields_by_name['Version'])
_MESSAGE_COMMAND.fields_by_name['Version'].containing_oneof = _MESSAGE_COMMAND.oneofs_by_name['kind']
_MESSAGE_COMMAND.oneofs_by_name['kind'].fields.append(
  _MESSAGE_COMMAND.fields_by_name['Verack'])
_MESSAGE_COMMAND.fields_by_name['Verack'].containing_oneof = _MESSAGE_COMMAND.oneofs_by_name['kind']
_MESSAGE_COMMAND.oneofs_by_name['kind'].fields.append(
  _MESSAGE_COMMAND.fields_by_name['GetPeers'])
_MESSAGE_COMMAND.fields_by_name['GetPeers'].containing_oneof = _MESSAGE_COMMAND.oneofs_by_name['kind']
_MESSAGE_COMMAND.oneofs_by_name['kind'].fields.append(
  _MESSAGE_COMMAND.fields_by_name['Peers'])
_MESSAGE_COMMAND.fields_by_name['Peers'].containing_oneof = _MESSAGE_COMMAND.oneofs_by_name['kind']
_MESSAGE_COMMAND.oneofs_by_name['kind'].fields.append(
  _MESSAGE_COMMAND.fields_by_name['Block'])
_MESSAGE_COMMAND.fields_by_name['Block'].containing_oneof = _MESSAGE_COMMAND.oneofs_by_name['kind']
_MESSAGE_COMMAND.oneofs_by_name['kind'].fields.append(
  _MESSAGE_COMMAND.fields_by_name['InventoryAnnouncement'])
_MESSAGE_COMMAND.fields_by_name['InventoryAnnouncement'].containing_oneof = _MESSAGE_COMMAND.oneofs_by_name['kind']
_MESSAGE_COMMAND.oneofs_by_name['kind'].fields.append(
  _MESSAGE_COMMAND.fields_by_name['InventoryRequest'])
_MESSAGE_COMMAND.fields_by_name['InventoryRequest'].containing_oneof = _MESSAGE_COMMAND.oneofs_by_name['kind']
_MESSAGE_COMMAND.oneofs_by_name['kind'].fields.append(
  _MESSAGE_COMMAND.fields_by_name['LastBeacon'])
_MESSAGE_COMMAND.fields_by_name['LastBeacon'].containing_oneof = _MESSAGE_COMMAND.oneofs_by_name['kind']
_MESSAGE_COMMAND.oneofs_by_name['kind'].fields.append(
  _MESSAGE_COMMAND.fields_by_name['Transaction'])
_MESSAGE_COMMAND.fields_by_name['Transaction'].containing_oneof = _MESSAGE_COMMAND.oneofs_by_name['kind']
_MESSAGE_COMMAND.oneofs_by_name['kind'].fields.append(
  _MESSAGE_COMMAND.fields_by_name['SuperBlockVote'])
_MESSAGE_COMMAND.fields_by_name['SuperBlockVote'].containing_oneof = _MESSAGE_COMMAND.oneofs_by_name['kind']
_MESSAGE.fields_by_name['kind'].message_type = _MESSAGE_COMMAND
_VERSION.fields_by_name['sender_address'].message_type = _ADDRESS
_VERSION.fields_by_name['receiver_address'].message_type = _ADDRESS
_PEERS.fields_by_name['peers'].message_type = _ADDRESS
_BLOCK_BLOCKELIGIBILITYCLAIM.fields_by_name['proof'].message_type = _VRFPROOF
_BLOCK_BLOCKELIGIBILITYCLAIM.containing_type = _BLOCK
_BLOCK_BLOCKHEADER_BLOCKMERKLEROOTS.fields_by_name['mint_hash'].message_type = _HASH
_BLOCK_BLOCKHEADER_BLOCKMERKLEROOTS.fields_by_name['vt_hash_merkle_root'].message_type = _HASH
_BLOCK_BLOCKHEADER_BLOCKMERKLEROOTS.fields_by_name['dr_hash_merkle_root'].message_type = _HASH
_BLOCK_BLOCKHEADER_BLOCKMERKLEROOTS.fields_by_name['commit_hash_merkle_root'].message_type = _HASH
_BLOCK_BLOCKHEADER_BLOCKMERKLEROOTS.fields_by_name['reveal_hash_merkle_root'].message_type = _HASH
_BLOCK_BLOCKHEADER_BLOCKMERKLEROOTS.fields_by_name['tally_hash_merkle_root'].message_type = _HASH
_BLOCK_BLOCKHEADER_BLOCKMERKLEROOTS.containing_type = _BLOCK_BLOCKHEADER
_BLOCK_BLOCKHEADER.fields_by_name['beacon'].message_type = _CHECKPOINTBEACON
_BLOCK_BLOCKHEADER.fields_by_name['merkle_roots'].message_type = _BLOCK_BLOCKHEADER_BLOCKMERKLEROOTS
_BLOCK_BLOCKHEADER.fields_by_name['proof'].message_type = _BLOCK_BLOCKELIGIBILITYCLAIM
_BLOCK_BLOCKHEADER.fields_by_name['bn256_public_key'].message_type = _BN256PUBLICKEY
_BLOCK_BLOCKHEADER.containing_type = _BLOCK
_BLOCK_BLOCKTRANSACTIONS.fields_by_name['mint'].message_type = _MINTTRANSACTION
_BLOCK_BLOCKTRANSACTIONS.fields_by_name['value_transfer_txns'].message_type = _VTTRANSACTION
_BLOCK_BLOCKTRANSACTIONS.fields_by_name['data_request_txns'].message_type = _DRTRANSACTION
_BLOCK_BLOCKTRANSACTIONS.fields_by_name['commit_txns'].message_type = _COMMITTRANSACTION
_BLOCK_BLOCKTRANSACTIONS.fields_by_name['reveal_txns'].message_type = _REVEALTRANSACTION
_BLOCK_BLOCKTRANSACTIONS.fields_by_name['tally_txns'].message_type = _TALLYTRANSACTION
_BLOCK_BLOCKTRANSACTIONS.containing_type = _BLOCK
_BLOCK.fields_by_name['block_header'].message_type = _BLOCK_BLOCKHEADER
_BLOCK.fields_by_name['block_sig'].message_type = _KEYEDSIGNATURE
_BLOCK.fields_by_name['txns'].message_type = _BLOCK_BLOCKTRANSACTIONS
_INVENTORYANNOUNCEMENT.fields_by_name['inventory'].message_type = _INVENTORYENTRY
_INVENTORYREQUEST.fields_by_name['inventory'].message_type = _INVENTORYENTRY
_LASTBEACON.fields_by_name['highest_block_checkpoint'].message_type = _CHECKPOINTBEACON
_OUTPUTPOINTER.fields_by_name['transaction_id'].message_type = _HASH
_VALUETRANSFEROUTPUT.fields_by_name['pkh'].message_type = _PUBLICKEYHASH
_DATAREQUESTOUTPUT_RADREQUEST_RADFILTER.containing_type = _DATAREQUESTOUTPUT_RADREQUEST
_DATAREQUESTOUTPUT_RADREQUEST_RADRETRIEVE.fields_by_name['kind'].enum_type = _DATAREQUESTOUTPUT_RADREQUEST_RADTYPE
_DATAREQUESTOUTPUT_RADREQUEST_RADRETRIEVE.containing_type = _DATAREQUESTOUTPUT_RADREQUEST
_DATAREQUESTOUTPUT_RADREQUEST_RADAGGREGATE.fields_by_name['filters'].message_type = _DATAREQUESTOUTPUT_RADREQUEST_RADFILTER
_DATAREQUESTOUTPUT_RADREQUEST_RADAGGREGATE.containing_type = _DATAREQUESTOUTPUT_RADREQUEST
_DATAREQUESTOUTPUT_RADREQUEST_RADTALLY.fields_by_name['filters'].message_type = _DATAREQUESTOUTPUT_RADREQUEST_RADFILTER
_DATAREQUESTOUTPUT_RADREQUEST_RADTALLY.containing_type = _DATAREQUESTOUTPUT_RADREQUEST
_DATAREQUESTOUTPUT_RADREQUEST.fields_by_name['retrieve'].message_type = _DATAREQUESTOUTPUT_RADREQUEST_RADRETRIEVE
_DATAREQUESTOUTPUT_RADREQUEST.fields_by_name['aggregate'].message_type = _DATAREQUESTOUTPUT_RADREQUEST_RADAGGREGATE
_DATAREQUESTOUTPUT_RADREQUEST.fields_by_name['tally'].message_type = _DATAREQUESTOUTPUT_RADREQUEST_RADTALLY
_DATAREQUESTOUTPUT_RADREQUEST.containing_type = _DATAREQUESTOUTPUT
_DATAREQUESTOUTPUT_RADREQUEST_RADTYPE.containing_type = _DATAREQUESTOUTPUT_RADREQUEST
_DATAREQUESTOUTPUT.fields_by_name['data_request'].message_type = _DATAREQUESTOUTPUT_RADREQUEST
_INPUT.fields_by_name['output_pointer'].message_type = _OUTPUTPOINTER
_VTTRANSACTIONBODY.fields_by_name['inputs'].message_type = _INPUT
_VTTRANSACTIONBODY.fields_by_name['outputs'].message_type = _VALUETRANSFEROUTPUT
_VTTRANSACTION.fields_by_name['body'].message_type = _VTTRANSACTIONBODY
_VTTRANSACTION.fields_by_name['signatures'].message_type = _KEYEDSIGNATURE
_DRTRANSACTIONBODY.fields_by_name['inputs'].message_type = _INPUT
_DRTRANSACTIONBODY.fields_by_name['outputs'].message_type = _VALUETRANSFEROUTPUT
_DRTRANSACTIONBODY.fields_by_name['dr_output'].message_type = _DATAREQUESTOUTPUT
_DRTRANSACTION.fields_by_name['body'].message_type = _DRTRANSACTIONBODY
_DRTRANSACTION.fields_by_name['signatures'].message_type = _KEYEDSIGNATURE
_COMMITTRANSACTIONBODY.fields_by_name['dr_pointer'].message_type = _HASH
_COMMITTRANSACTIONBODY.fields_by_name['commitment'].message_type = _HASH
_COMMITTRANSACTIONBODY.fields_by_name['proof'].message_type = _DATAREQUESTELIGIBILITYCLAIM
_COMMITTRANSACTIONBODY.fields_by_name['collateral'].message_type = _INPUT
_COMMITTRANSACTIONBODY.fields_by_name['outputs'].message_type = _VALUETRANSFEROUTPUT
_COMMITTRANSACTIONBODY.fields_by_name['bn256_public_key'].message_type = _BN256PUBLICKEY
_COMMITTRANSACTION.fields_by_name['body'].message_type = _COMMITTRANSACTIONBODY
_COMMITTRANSACTION.fields_by_name['signatures'].message_type = _KEYEDSIGNATURE
_REVEALTRANSACTIONBODY.fields_by_name['dr_pointer'].message_type = _HASH
_REVEALTRANSACTIONBODY.fields_by_name['pkh'].message_type = _PUBLICKEYHASH
_REVEALTRANSACTION.fields_by_name['body'].message_type = _REVEALTRANSACTIONBODY
_REVEALTRANSACTION.fields_by_name['signatures'].message_type = _KEYEDSIGNATURE
_TALLYTRANSACTION.fields_by_name['dr_pointer'].message_type = _HASH
_TALLYTRANSACTION.fields_by_name['outputs'].message_type = _VALUETRANSFEROUTPUT
_TALLYTRANSACTION.fields_by_name['out_of_consensus'].message_type = _PUBLICKEYHASH
_TALLYTRANSACTION.fields_by_name['error_committers'].message_type = _PUBLICKEYHASH
_MINTTRANSACTION.fields_by_name['outputs'].message_type = _VALUETRANSFEROUTPUT
_TRANSACTION.fields_by_name['ValueTransfer'].message_type = _VTTRANSACTION
_TRANSACTION.fields_by_name['DataRequest'].message_type = _DRTRANSACTION
_TRANSACTION.fields_by_name['Commit'].message_type = _COMMITTRANSACTION
_TRANSACTION.fields_by_name['Reveal'].message_type = _REVEALTRANSACTION
_TRANSACTION.fields_by_name['Tally'].message_type = _TALLYTRANSACTION
_TRANSACTION.fields_by_name['Mint'].message_type = _MINTTRANSACTION
_TRANSACTION.oneofs_by_name['kind'].fields.append(
  _TRANSACTION.fields_by_name['ValueTransfer'])
_TRANSACTION.fields_by_name['ValueTransfer'].containing_oneof = _TRANSACTION.oneofs_by_name['kind']
_TRANSACTION.oneofs_by_name['kind'].fields.append(
  _TRANSACTION.fields_by_name['DataRequest'])
_TRANSACTION.fields_by_name['DataRequest'].containing_oneof = _TRANSACTION.oneofs_by_name['kind']
_TRANSACTION.oneofs_by_name['kind'].fields.append(
  _TRANSACTION.fields_by_name['Commit'])
_TRANSACTION.fields_by_name['Commit'].containing_oneof = _TRANSACTION.oneofs_by_name['kind']
_TRANSACTION.oneofs_by_name['kind'].fields.append(
  _TRANSACTION.fields_by_name['Reveal'])
_TRANSACTION.fields_by_name['Reveal'].containing_oneof = _TRANSACTION.oneofs_by_name['kind']
_TRANSACTION.oneofs_by_name['kind'].fields.append(
  _TRANSACTION.fields_by_name['Tally'])
_TRANSACTION.fields_by_name['Tally'].containing_oneof = _TRANSACTION.oneofs_by_name['kind']
_TRANSACTION.oneofs_by_name['kind'].fields.append(
  _TRANSACTION.fields_by_name['Mint'])
_TRANSACTION.fields_by_name['Mint'].containing_oneof = _TRANSACTION.oneofs_by_name['kind']
_HASH.oneofs_by_name['kind'].fields.append(
  _HASH.fields_by_name['SHA256'])
_HASH.fields_by_name['SHA256'].containing_oneof = _HASH.oneofs_by_name['kind']
_SIGNATURE.fields_by_name['Secp256k1'].message_type = _SECP256K1SIGNATURE
_SIGNATURE.oneofs_by_name['kind'].fields.append(
  _SIGNATURE.fields_by_name['Secp256k1'])
_SIGNATURE.fields_by_name['Secp256k1'].containing_oneof = _SIGNATURE.oneofs_by_name['kind']
_KEYEDSIGNATURE.fields_by_name['signature'].message_type = _SIGNATURE
_KEYEDSIGNATURE.fields_by_name['public_key'].message_type = _PUBLICKEY
_BN256KEYEDSIGNATURE.fields_by_name['signature'].message_type = _BN256SIGNATURE
_BN256KEYEDSIGNATURE.fields_by_name['public_key'].message_type = _BN256PUBLICKEY
_CHECKPOINTBEACON.fields_by_name['hash_prev_block'].message_type = _HASH
_CHECKPOINTVRF.fields_by_name['hash_prev_vrf'].message_type = _HASH
_INVENTORYENTRY.fields_by_name['Block'].message_type = _HASH
_INVENTORYENTRY.fields_by_name['Tx'].message_type = _HASH
_INVENTORYENTRY.oneofs_by_name['kind'].fields.append(
  _INVENTORYENTRY.fields_by_name['Block'])
_INVENTORYENTRY.fields_by_name['Block'].containing_oneof = _INVENTORYENTRY.oneofs_by_name['kind']
_INVENTORYENTRY.oneofs_by_name['kind'].fields.append(
  _INVENTORYENTRY.fields_by_name['Tx'])
_INVENTORYENTRY.fields_by_name['Tx'].containing_oneof = _INVENTORYENTRY.oneofs_by_name['kind']
_CONSENSUSCONSTANTS.fields_by_name['bootstrap_hash'].message_type = _HASH
_CONSENSUSCONSTANTS.fields_by_name['genesis_hash'].message_type = _HASH
_VRFPROOF.fields_by_name['public_key'].message_type = _PUBLICKEY
_DATAREQUESTVRFMESSAGE.fields_by_name['vrf_input'].message_type = _CHECKPOINTVRF
_DATAREQUESTVRFMESSAGE.fields_by_name['dr_hash'].message_type = _HASH
_DATAREQUESTELIGIBILITYCLAIM.fields_by_name['proof'].message_type = _VRFPROOF
_SUPERBLOCK.fields_by_name['ars_root'].message_type = _HASH
_SUPERBLOCK.fields_by_name['data_request_root'].message_type = _HASH
_SUPERBLOCK.fields_by_name['last_block'].message_type = _HASH
_SUPERBLOCK.fields_by_name['last_block_in_previous_superblock'].message_type = _HASH
_SUPERBLOCK.fields_by_name['tally_root'].message_type = _HASH
_SUPERBLOCKVOTE.fields_by_name['bn256_signature'].message_type = _BN256SIGNATURE
_SUPERBLOCKVOTE.fields_by_name['secp256k1_signature'].message_type = _KEYEDSIGNATURE
_SUPERBLOCKVOTE.fields_by_name['superblock_hash'].message_type = _HASH
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.message_types_by_name['Version'] = _VERSION
DESCRIPTOR.message_types_by_name['Verack'] = _VERACK
DESCRIPTOR.message_types_by_name['GetPeers'] = _GETPEERS
DESCRIPTOR.message_types_by_name['Peers'] = _PEERS
DESCRIPTOR.message_types_by_name['Block'] = _BLOCK
DESCRIPTOR.message_types_by_name['InventoryAnnouncement'] = _INVENTORYANNOUNCEMENT
DESCRIPTOR.message_types_by_name['InventoryRequest'] = _INVENTORYREQUEST
DESCRIPTOR.message_types_by_name['LastBeacon'] = _LASTBEACON
DESCRIPTOR.message_types_by_name['OutputPointer'] = _OUTPUTPOINTER
DESCRIPTOR.message_types_by_name['ValueTransferOutput'] = _VALUETRANSFEROUTPUT
DESCRIPTOR.message_types_by_name['DataRequestOutput'] = _DATAREQUESTOUTPUT
DESCRIPTOR.message_types_by_name['Input'] = _INPUT
DESCRIPTOR.message_types_by_name['VTTransactionBody'] = _VTTRANSACTIONBODY
DESCRIPTOR.message_types_by_name['VTTransaction'] = _VTTRANSACTION
DESCRIPTOR.message_types_by_name['DRTransactionBody'] = _DRTRANSACTIONBODY
DESCRIPTOR.message_types_by_name['DRTransaction'] = _DRTRANSACTION
DESCRIPTOR.message_types_by_name['CommitTransactionBody'] = _COMMITTRANSACTIONBODY
DESCRIPTOR.message_types_by_name['CommitTransaction'] = _COMMITTRANSACTION
DESCRIPTOR.message_types_by_name['RevealTransactionBody'] = _REVEALTRANSACTIONBODY
DESCRIPTOR.message_types_by_name['RevealTransaction'] = _REVEALTRANSACTION
DESCRIPTOR.message_types_by_name['TallyTransaction'] = _TALLYTRANSACTION
DESCRIPTOR.message_types_by_name['MintTransaction'] = _MINTTRANSACTION
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
DESCRIPTOR.message_types_by_name['Hash'] = _HASH
DESCRIPTOR.message_types_by_name['Secp256k1Signature'] = _SECP256K1SIGNATURE
DESCRIPTOR.message_types_by_name['Signature'] = _SIGNATURE
DESCRIPTOR.message_types_by_name['Bn256Signature'] = _BN256SIGNATURE
DESCRIPTOR.message_types_by_name['PublicKey'] = _PUBLICKEY
DESCRIPTOR.message_types_by_name['Bn256PublicKey'] = _BN256PUBLICKEY
DESCRIPTOR.message_types_by_name['PublicKeyHash'] = _PUBLICKEYHASH
DESCRIPTOR.message_types_by_name['KeyedSignature'] = _KEYEDSIGNATURE
DESCRIPTOR.message_types_by_name['Bn256KeyedSignature'] = _BN256KEYEDSIGNATURE
DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
DESCRIPTOR.message_types_by_name['CheckpointBeacon'] = _CHECKPOINTBEACON
DESCRIPTOR.message_types_by_name['CheckpointVRF'] = _CHECKPOINTVRF
DESCRIPTOR.message_types_by_name['InventoryEntry'] = _INVENTORYENTRY
DESCRIPTOR.message_types_by_name['ConsensusConstants'] = _CONSENSUSCONSTANTS
DESCRIPTOR.message_types_by_name['VrfProof'] = _VRFPROOF
DESCRIPTOR.message_types_by_name['DataRequestVrfMessage'] = _DATAREQUESTVRFMESSAGE
DESCRIPTOR.message_types_by_name['DataRequestEligibilityClaim'] = _DATAREQUESTELIGIBILITYCLAIM
DESCRIPTOR.message_types_by_name['SuperBlock'] = _SUPERBLOCK
DESCRIPTOR.message_types_by_name['SuperBlockVote'] = _SUPERBLOCKVOTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {

  'Command' : _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), {
    'DESCRIPTOR' : _MESSAGE_COMMAND,
    '__module__' : 'witnet_pb2'
    # @@protoc_insertion_point(class_scope:witnet.Message.Command)
    })
  ,
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Message)
  })
_sym_db.RegisterMessage(Message)
_sym_db.RegisterMessage(Message.Command)

Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {
  'DESCRIPTOR' : _VERSION,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Version)
  })
_sym_db.RegisterMessage(Version)

Verack = _reflection.GeneratedProtocolMessageType('Verack', (_message.Message,), {
  'DESCRIPTOR' : _VERACK,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Verack)
  })
_sym_db.RegisterMessage(Verack)

GetPeers = _reflection.GeneratedProtocolMessageType('GetPeers', (_message.Message,), {
  'DESCRIPTOR' : _GETPEERS,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.GetPeers)
  })
_sym_db.RegisterMessage(GetPeers)

Peers = _reflection.GeneratedProtocolMessageType('Peers', (_message.Message,), {
  'DESCRIPTOR' : _PEERS,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Peers)
  })
_sym_db.RegisterMessage(Peers)

Block = _reflection.GeneratedProtocolMessageType('Block', (_message.Message,), {

  'BlockEligibilityClaim' : _reflection.GeneratedProtocolMessageType('BlockEligibilityClaim', (_message.Message,), {
    'DESCRIPTOR' : _BLOCK_BLOCKELIGIBILITYCLAIM,
    '__module__' : 'witnet_pb2'
    # @@protoc_insertion_point(class_scope:witnet.Block.BlockEligibilityClaim)
    })
  ,

  'BlockHeader' : _reflection.GeneratedProtocolMessageType('BlockHeader', (_message.Message,), {

    'BlockMerkleRoots' : _reflection.GeneratedProtocolMessageType('BlockMerkleRoots', (_message.Message,), {
      'DESCRIPTOR' : _BLOCK_BLOCKHEADER_BLOCKMERKLEROOTS,
      '__module__' : 'witnet_pb2'
      # @@protoc_insertion_point(class_scope:witnet.Block.BlockHeader.BlockMerkleRoots)
      })
    ,
    'DESCRIPTOR' : _BLOCK_BLOCKHEADER,
    '__module__' : 'witnet_pb2'
    # @@protoc_insertion_point(class_scope:witnet.Block.BlockHeader)
    })
  ,

  'BlockTransactions' : _reflection.GeneratedProtocolMessageType('BlockTransactions', (_message.Message,), {
    'DESCRIPTOR' : _BLOCK_BLOCKTRANSACTIONS,
    '__module__' : 'witnet_pb2'
    # @@protoc_insertion_point(class_scope:witnet.Block.BlockTransactions)
    })
  ,
  'DESCRIPTOR' : _BLOCK,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Block)
  })
_sym_db.RegisterMessage(Block)
_sym_db.RegisterMessage(Block.BlockEligibilityClaim)
_sym_db.RegisterMessage(Block.BlockHeader)
_sym_db.RegisterMessage(Block.BlockHeader.BlockMerkleRoots)
_sym_db.RegisterMessage(Block.BlockTransactions)

InventoryAnnouncement = _reflection.GeneratedProtocolMessageType('InventoryAnnouncement', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYANNOUNCEMENT,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.InventoryAnnouncement)
  })
_sym_db.RegisterMessage(InventoryAnnouncement)

InventoryRequest = _reflection.GeneratedProtocolMessageType('InventoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYREQUEST,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.InventoryRequest)
  })
_sym_db.RegisterMessage(InventoryRequest)

LastBeacon = _reflection.GeneratedProtocolMessageType('LastBeacon', (_message.Message,), {
  'DESCRIPTOR' : _LASTBEACON,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.LastBeacon)
  })
_sym_db.RegisterMessage(LastBeacon)

OutputPointer = _reflection.GeneratedProtocolMessageType('OutputPointer', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUTPOINTER,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.OutputPointer)
  })
_sym_db.RegisterMessage(OutputPointer)

ValueTransferOutput = _reflection.GeneratedProtocolMessageType('ValueTransferOutput', (_message.Message,), {
  'DESCRIPTOR' : _VALUETRANSFEROUTPUT,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.ValueTransferOutput)
  })
_sym_db.RegisterMessage(ValueTransferOutput)

DataRequestOutput = _reflection.GeneratedProtocolMessageType('DataRequestOutput', (_message.Message,), {

  'RADRequest' : _reflection.GeneratedProtocolMessageType('RADRequest', (_message.Message,), {

    'RADFilter' : _reflection.GeneratedProtocolMessageType('RADFilter', (_message.Message,), {
      'DESCRIPTOR' : _DATAREQUESTOUTPUT_RADREQUEST_RADFILTER,
      '__module__' : 'witnet_pb2'
      # @@protoc_insertion_point(class_scope:witnet.DataRequestOutput.RADRequest.RADFilter)
      })
    ,

    'RADRetrieve' : _reflection.GeneratedProtocolMessageType('RADRetrieve', (_message.Message,), {
      'DESCRIPTOR' : _DATAREQUESTOUTPUT_RADREQUEST_RADRETRIEVE,
      '__module__' : 'witnet_pb2'
      # @@protoc_insertion_point(class_scope:witnet.DataRequestOutput.RADRequest.RADRetrieve)
      })
    ,

    'RADAggregate' : _reflection.GeneratedProtocolMessageType('RADAggregate', (_message.Message,), {
      'DESCRIPTOR' : _DATAREQUESTOUTPUT_RADREQUEST_RADAGGREGATE,
      '__module__' : 'witnet_pb2'
      # @@protoc_insertion_point(class_scope:witnet.DataRequestOutput.RADRequest.RADAggregate)
      })
    ,

    'RADTally' : _reflection.GeneratedProtocolMessageType('RADTally', (_message.Message,), {
      'DESCRIPTOR' : _DATAREQUESTOUTPUT_RADREQUEST_RADTALLY,
      '__module__' : 'witnet_pb2'
      # @@protoc_insertion_point(class_scope:witnet.DataRequestOutput.RADRequest.RADTally)
      })
    ,
    'DESCRIPTOR' : _DATAREQUESTOUTPUT_RADREQUEST,
    '__module__' : 'witnet_pb2'
    # @@protoc_insertion_point(class_scope:witnet.DataRequestOutput.RADRequest)
    })
  ,
  'DESCRIPTOR' : _DATAREQUESTOUTPUT,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.DataRequestOutput)
  })
_sym_db.RegisterMessage(DataRequestOutput)
_sym_db.RegisterMessage(DataRequestOutput.RADRequest)
_sym_db.RegisterMessage(DataRequestOutput.RADRequest.RADFilter)
_sym_db.RegisterMessage(DataRequestOutput.RADRequest.RADRetrieve)
_sym_db.RegisterMessage(DataRequestOutput.RADRequest.RADAggregate)
_sym_db.RegisterMessage(DataRequestOutput.RADRequest.RADTally)

Input = _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), {
  'DESCRIPTOR' : _INPUT,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Input)
  })
_sym_db.RegisterMessage(Input)

VTTransactionBody = _reflection.GeneratedProtocolMessageType('VTTransactionBody', (_message.Message,), {
  'DESCRIPTOR' : _VTTRANSACTIONBODY,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.VTTransactionBody)
  })
_sym_db.RegisterMessage(VTTransactionBody)

VTTransaction = _reflection.GeneratedProtocolMessageType('VTTransaction', (_message.Message,), {
  'DESCRIPTOR' : _VTTRANSACTION,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.VTTransaction)
  })
_sym_db.RegisterMessage(VTTransaction)

DRTransactionBody = _reflection.GeneratedProtocolMessageType('DRTransactionBody', (_message.Message,), {
  'DESCRIPTOR' : _DRTRANSACTIONBODY,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.DRTransactionBody)
  })
_sym_db.RegisterMessage(DRTransactionBody)

DRTransaction = _reflection.GeneratedProtocolMessageType('DRTransaction', (_message.Message,), {
  'DESCRIPTOR' : _DRTRANSACTION,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.DRTransaction)
  })
_sym_db.RegisterMessage(DRTransaction)

CommitTransactionBody = _reflection.GeneratedProtocolMessageType('CommitTransactionBody', (_message.Message,), {
  'DESCRIPTOR' : _COMMITTRANSACTIONBODY,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.CommitTransactionBody)
  })
_sym_db.RegisterMessage(CommitTransactionBody)

CommitTransaction = _reflection.GeneratedProtocolMessageType('CommitTransaction', (_message.Message,), {
  'DESCRIPTOR' : _COMMITTRANSACTION,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.CommitTransaction)
  })
_sym_db.RegisterMessage(CommitTransaction)

RevealTransactionBody = _reflection.GeneratedProtocolMessageType('RevealTransactionBody', (_message.Message,), {
  'DESCRIPTOR' : _REVEALTRANSACTIONBODY,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.RevealTransactionBody)
  })
_sym_db.RegisterMessage(RevealTransactionBody)

RevealTransaction = _reflection.GeneratedProtocolMessageType('RevealTransaction', (_message.Message,), {
  'DESCRIPTOR' : _REVEALTRANSACTION,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.RevealTransaction)
  })
_sym_db.RegisterMessage(RevealTransaction)

TallyTransaction = _reflection.GeneratedProtocolMessageType('TallyTransaction', (_message.Message,), {
  'DESCRIPTOR' : _TALLYTRANSACTION,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.TallyTransaction)
  })
_sym_db.RegisterMessage(TallyTransaction)

MintTransaction = _reflection.GeneratedProtocolMessageType('MintTransaction', (_message.Message,), {
  'DESCRIPTOR' : _MINTTRANSACTION,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.MintTransaction)
  })
_sym_db.RegisterMessage(MintTransaction)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTION,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Transaction)
  })
_sym_db.RegisterMessage(Transaction)

Hash = _reflection.GeneratedProtocolMessageType('Hash', (_message.Message,), {
  'DESCRIPTOR' : _HASH,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Hash)
  })
_sym_db.RegisterMessage(Hash)

Secp256k1Signature = _reflection.GeneratedProtocolMessageType('Secp256k1Signature', (_message.Message,), {
  'DESCRIPTOR' : _SECP256K1SIGNATURE,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Secp256k1Signature)
  })
_sym_db.RegisterMessage(Secp256k1Signature)

Signature = _reflection.GeneratedProtocolMessageType('Signature', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATURE,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Signature)
  })
_sym_db.RegisterMessage(Signature)

Bn256Signature = _reflection.GeneratedProtocolMessageType('Bn256Signature', (_message.Message,), {
  'DESCRIPTOR' : _BN256SIGNATURE,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Bn256Signature)
  })
_sym_db.RegisterMessage(Bn256Signature)

PublicKey = _reflection.GeneratedProtocolMessageType('PublicKey', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICKEY,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.PublicKey)
  })
_sym_db.RegisterMessage(PublicKey)

Bn256PublicKey = _reflection.GeneratedProtocolMessageType('Bn256PublicKey', (_message.Message,), {
  'DESCRIPTOR' : _BN256PUBLICKEY,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Bn256PublicKey)
  })
_sym_db.RegisterMessage(Bn256PublicKey)

PublicKeyHash = _reflection.GeneratedProtocolMessageType('PublicKeyHash', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICKEYHASH,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.PublicKeyHash)
  })
_sym_db.RegisterMessage(PublicKeyHash)

KeyedSignature = _reflection.GeneratedProtocolMessageType('KeyedSignature', (_message.Message,), {
  'DESCRIPTOR' : _KEYEDSIGNATURE,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.KeyedSignature)
  })
_sym_db.RegisterMessage(KeyedSignature)

Bn256KeyedSignature = _reflection.GeneratedProtocolMessageType('Bn256KeyedSignature', (_message.Message,), {
  'DESCRIPTOR' : _BN256KEYEDSIGNATURE,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Bn256KeyedSignature)
  })
_sym_db.RegisterMessage(Bn256KeyedSignature)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.Address)
  })
_sym_db.RegisterMessage(Address)

CheckpointBeacon = _reflection.GeneratedProtocolMessageType('CheckpointBeacon', (_message.Message,), {
  'DESCRIPTOR' : _CHECKPOINTBEACON,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.CheckpointBeacon)
  })
_sym_db.RegisterMessage(CheckpointBeacon)

CheckpointVRF = _reflection.GeneratedProtocolMessageType('CheckpointVRF', (_message.Message,), {
  'DESCRIPTOR' : _CHECKPOINTVRF,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.CheckpointVRF)
  })
_sym_db.RegisterMessage(CheckpointVRF)

InventoryEntry = _reflection.GeneratedProtocolMessageType('InventoryEntry', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYENTRY,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.InventoryEntry)
  })
_sym_db.RegisterMessage(InventoryEntry)

ConsensusConstants = _reflection.GeneratedProtocolMessageType('ConsensusConstants', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSCONSTANTS,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.ConsensusConstants)
  })
_sym_db.RegisterMessage(ConsensusConstants)

VrfProof = _reflection.GeneratedProtocolMessageType('VrfProof', (_message.Message,), {
  'DESCRIPTOR' : _VRFPROOF,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.VrfProof)
  })
_sym_db.RegisterMessage(VrfProof)

DataRequestVrfMessage = _reflection.GeneratedProtocolMessageType('DataRequestVrfMessage', (_message.Message,), {
  'DESCRIPTOR' : _DATAREQUESTVRFMESSAGE,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.DataRequestVrfMessage)
  })
_sym_db.RegisterMessage(DataRequestVrfMessage)

DataRequestEligibilityClaim = _reflection.GeneratedProtocolMessageType('DataRequestEligibilityClaim', (_message.Message,), {
  'DESCRIPTOR' : _DATAREQUESTELIGIBILITYCLAIM,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.DataRequestEligibilityClaim)
  })
_sym_db.RegisterMessage(DataRequestEligibilityClaim)

SuperBlock = _reflection.GeneratedProtocolMessageType('SuperBlock', (_message.Message,), {
  'DESCRIPTOR' : _SUPERBLOCK,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.SuperBlock)
  })
_sym_db.RegisterMessage(SuperBlock)

SuperBlockVote = _reflection.GeneratedProtocolMessageType('SuperBlockVote', (_message.Message,), {
  'DESCRIPTOR' : _SUPERBLOCKVOTE,
  '__module__' : 'witnet_pb2'
  # @@protoc_insertion_point(class_scope:witnet.SuperBlockVote)
  })
_sym_db.RegisterMessage(SuperBlockVote)


# @@protoc_insertion_point(module_scope)
